package com.zcloud.mapper.datasource.inspection;

import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;

import java.util.List;

/**
 * 说明：安全环保检查
 * 作者：luoxiaobao
 * 时间：2022-06-08
 * 官网：www.zcloudchina.com
 */
public interface SafetyEnvironmentalMapper{

	/**新增
	 * @param pd
	 * @throws Exception
	 */
	void save(PageData pd);

	/**删除
	 * @param pd
	 * @throws Exception
	 */
	void delete(PageData pd);

	/**修改
	 * @param pd
	 * @throws Exception
	 */
	void edit(PageData pd);
	/**修改
	 * @param pd
	 * @throws Exception
	 */
	void edieditsttust(PageData pd); //执行考评方法时，将检查状态改成已归档，因为bug6535提出，要是隐患考评完毕，状态应该是8已归档
	/**列表
	 * @param page
	 * @throws Exception
	 */
	List<PageData> datalistPage(Page page);

	/**列表(全部)
	 * @param pd
	 * @throws Exception
	 */
	List<PageData> listAll(PageData pd);

	/**列表(全部)
	 * @param pd
	 * @throws Exception
	 */
	List<PageData> findByyin(PageData pd);

	/**通过id获取数据
	 * @param pd
	 * @throws Exception
	 */
	PageData findById(PageData pd);

	/**批量删除
	 * @param pd
	 * @throws Exception
	 */
	void deleteAll(PageData pd);

	/**列表(根据所选ID获取数据)
	 * @param pd
	 * @throws Exception
	 */
	List<PageData> findByIds(PageData pd);

	/**
	 * 更新检查进度状态
	 * @param pd
	 */
	void editStatus(PageData pd);

	/**
	 * 分公司安全环保检查考核分数统计
	 * @param pd
	 * @return
	 */
	PageData statisticsBranch(PageData pd);

	List<PageData> getHiddenCountByDepat (PageData pd);

	List<PageData> getHiddenCountByUser (PageData pd);

	/**
	 * 列表（股份公司安全环保检查考核分数统计）
	 * @param pd
	 * @return
	 */
	List<PageData> statisticsJointStock(PageData pd);

    PageData checkedCount(PageData pd);

	PageData repulseCount(PageData pd);

	PageData repulseAndCheckCountCount(PageData pd);

	List<PageData> pleadlistPage(Page page);

    List<PageData> checklistPage(Page page);
	List<PageData> statisticsBranchGroupDept(PageData pd);

	String getHiddenTotal(Page page);

	PageData repulseAndCheckCountCountV2(PageData pd);

}

