package com.zcloud.service.inspection;

import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;

import java.util.List;

/**
 * 说明：安全环保检查
 * 作者：luoxiaobao
 * 时间：2022-06-08
 * 官网：www.zcloudchina.com
 */
public interface SafetyEnvironmentalService{
	List<PageData> getHiddenCountByDepat (PageData pd) throws Exception;
	List<PageData> getHiddenCountByUser (PageData pd) throws Exception;
	/**新增
	 * @param pd
	 * @throws Exception
	 */
	public List<PageData> save(PageData pd)throws Exception;

	/**删除
	 * @param pd
	 * @throws Exception
	 */
	public void delete(PageData pd)throws Exception;

	/**修改
	 * @param pd
	 * @throws Exception
	 */
	public List<PageData> edit(PageData pd)throws Exception;

	/**修改
	 * @param pd
	 * @throws Exception
	 */
	public void edieditsttust(PageData pd)throws Exception; //执行考评方法时，将检查状态改成已归档，因为bug6535提出，要是隐患考评完毕，状态应该是8已归档

	/**列表
	 * @param page
	 * @throws Exception
	 */
	public List<PageData> list(Page page)throws Exception;

	/**列表(全部)
	 * @param pd
	 * @throws Exception
	 */
	public List<PageData> listAll(PageData pd)throws Exception;

	/**列表(全部)
	 * @param pd
	 * @throws Exception
	 */
	public List<PageData> findByyin(PageData pd)throws Exception;
	/**通过id获取数据
	 * @param pd
	 * @throws Exception
	 */
	public PageData findById(PageData pd)throws Exception;

	/**批量删除
	 * @param pd
	 * @throws Exception
	 */
	public void deleteAll(PageData pd)throws Exception;

	/**列表(根据所选ID获取数据)
	 * @param pd
	 * @throws Exception
	 */
	List<PageData> findByIds(PageData pd)throws Exception;

	/**
	 * 更新检查进度状态
	 * @param pd
	 */
    void editStatus(PageData pd)throws Exception;

	PageData findShowById(PageData pd)throws Exception;

	/**
	 * 获取检查所有相关信息
	 * @param pd
	 * @return
	 */
	PageData findFormById(PageData pd)throws Exception;

	/**
	 * 申辩不成立时归档
	 * @param pd
	 * @throws Exception
	 */
	void explain(PageData pd)throws Exception;

	/**
	 * 分公司安全环保检查考核分数统计
	 * @param pd
	 * @return
	 * @throws Exception
	 */
    PageData statisticsBranch(PageData pd)throws Exception;

	/**
	 * 列表（股份公司安全环保检查考核分数统计）
	 * @param pd
	 * @return
	 * @throws Exception
	 */
	List<PageData> statisticsJointStock(PageData pd) throws Exception;

	/**
	 * 被检查人签字/申辩数
	 * @param pd
	 * @return
	 * @throws Exception
	 */
	PageData checkedCount (PageData pd)throws Exception;

	/**
	 * 打回数
	 * @param pd
	 * @return
	 * @throws Exception
	 */
	PageData repulseCount (PageData pd)throws Exception;

	/**
	 * 指派+验收数
	 * @param pd
	 * @return
	 * @throws Exception
	 */
	PageData repulseAndCheckCountCount (PageData pd)throws Exception;

	List<PageData> pleadList(Page page) throws Exception;

    List<PageData> checkList(Page page) ;

	/**
	 * description: 公司层级工具类
	 *
	 * @param data
	 * @return
	 * @throws Exception
	 */
	PageData departmentUtil(PageData data) throws Exception;
	/**
	 *  获取所有的安全环保信息
	 * @param pd
	 * @return
	 * @throws Exception
	 */
	List<PageData> statisticsBranchGroupDept(PageData pd) throws Exception;

	String getHiddenTotal(Page page);
	/**
	 * 指派+验收数  验收数据错误,原来可以查询已经验收数据
	 * @param pd
	 * @return
	 * @throws Exception
	 */
	PageData repulseAndCheckCountCountV2 (PageData pd)throws Exception;

}

